@@ -4,11 +4,13 @@ from dataclasses import dataclass
 @dataclass
 class ShinobiClient:
     """
-    Model of Shinobi installation.
+    Shinobi client.
+
+    Not thread safe.
     """
     host: str
     port: str
-    super_user_token: str
+    super_user_token: str = None
     super_user_email: str = None
     super_user_password: str = None
 
@@ -25,3 +27,7 @@ class ShinobiClient:
     def api_key(self) -> "ShinobiApiKey":
         from shinobi_client.api_key import ShinobiApiKey
         return ShinobiApiKey(self)
+
+    def monitor(self, email: str, password: str) -> "ShinobiMonitor":
+        from shinobi_client.orms.monitor import ShinobiMonitorOrm
+        return ShinobiMonitorOrm(self, email, password)
