@@ -9,13 +9,13 @@ class TestShinobiClient(TestWithShinobi):
     """
     def test_get_user(self):
         email, password = _create_email_and_password()
-        self._shinobi_client.user.create(email, password)
-        self.assertIsNotNone(self._shinobi_client.user.get(email))
+        self.shinobi_client.user.create(email, password)
+        self.assertIsNotNone(self.shinobi_client.user.get(email))
 
     def test_get_api_key(self):
         email, password = _create_email_and_password()
-        self._shinobi_client.user.create(email, password)
-        self.assertIsNotNone(self._shinobi_client.api_key.get(email, password))
+        self.shinobi_client.user.create(email, password)
+        self.assertIsNotNone(self.shinobi_client.api_key.get(email, password))
 
 
 if __name__ == "__main__":
